]> git.cameronkatri.com Git - mandoc.git/blobdiff - libroff.h
delete some TODO entries that were already fixed
[mandoc.git] / libroff.h
index 964cd48a1f92671e6e6ef51622f034fa830be8e9..08ed1f7925d2332837650cb424ec248e1fad8fd7 100644 (file)
--- a/libroff.h
+++ b/libroff.h
@@ -1,6 +1,7 @@
-/*     $Id: libroff.h,v 1.4 2010/12/29 01:18:23 kristaps Exp $ */
+/*     $Id: libroff.h,v 1.38 2015/01/30 04:11:50 schwarze Exp $ */
 /*
 /*
- * Copyright (c) 2009, 2010 Kristaps Dzonsons <kristaps@bsd.lv>
+ * Copyright (c) 2009, 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
+ * Copyright (c) 2014, 2015 Ingo Schwarze <schwarze@openbsd.org>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
  * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
-#ifndef LIBROFF_H
-#define LIBROFF_H
-
-__BEGIN_DECLS
 
 enum   tbl_part {
        TBL_PART_OPTS, /* in options (first line) */
        TBL_PART_LAYOUT, /* describing layout */
 
 enum   tbl_part {
        TBL_PART_OPTS, /* in options (first line) */
        TBL_PART_LAYOUT, /* describing layout */
-       TBL_PART_DATA  /* creating data rows */
+       TBL_PART_DATA, /* creating data rows */
+       TBL_PART_CDATA /* continue previous row */
 };
 
 };
 
-struct tbl {
-       mandocmsg        msg; /* status messages */
-       void            *data; /* privdata for messages */
+struct tbl_node {
+       struct mparse    *parse; /* parse point */
+       int               pos; /* invocation column */
+       int               line; /* invocation line */
        enum tbl_part     part;
        enum tbl_part     part;
-       char              tab; /* cell-separator */
-       char              decimal; /* decimal point */
-       int               linesize;
-       char              delims[2];
-       int               opts;
-#define        TBL_OPT_CENTRE   (1 << 0)
-#define        TBL_OPT_EXPAND   (1 << 1)
-#define        TBL_OPT_BOX      (1 << 2)
-#define        TBL_OPT_DBOX     (1 << 3)
-#define        TBL_OPT_ALLBOX   (1 << 4)
-#define        TBL_OPT_NOKEEP   (1 << 5)
-#define        TBL_OPT_NOSPACE  (1 << 6)
+       struct tbl_opts   opts;
+       struct tbl_row   *first_row;
+       struct tbl_row   *last_row;
+       struct tbl_span  *first_span;
+       struct tbl_span  *current_span;
+       struct tbl_span  *last_span;
+       struct tbl_node  *next;
+};
+
+struct eqn_node {
+       struct eqn        eqn;    /* syntax tree of this equation */
+       struct mparse    *parse;  /* main parser, for error reporting */
+       struct eqn_node  *next;   /* singly linked list of equations */
+       struct eqn_def   *defs;   /* array of definitions */
+       char             *data;   /* source code of this equation */
+       size_t            defsz;  /* number of definitions */
+       size_t            sz;     /* length of the source code */
+       size_t            cur;    /* parse point in the source code */
+       size_t            rew;    /* beginning of the current token */
+       int               gsize;  /* default point size */
+       int               delim;  /* in-line delimiters enabled */
+       char              odelim; /* in-line opening delimiter */
+       char              cdelim; /* in-line closing delimiter */
 };
 
 };
 
-#define        TBL_MSG(tblp, type, line, col) \
-       (*(tblp)->msg)((type), (tblp)->data, (line), (col), NULL)
+struct eqn_def {
+       char             *key;
+       size_t            keysz;
+       char             *val;
+       size_t            valsz;
+};
+
+__BEGIN_DECLS
 
 
-struct tbl     *tbl_alloc(void *, mandocmsg);
-void            tbl_free(struct tbl *);
-void            tbl_reset(struct tbl *);
-enum rofferr    tbl_read(struct tbl *, int, const char *, int);
-int             tbl_option(struct tbl *, int, const char *);
+struct tbl_node        *tbl_alloc(int, int, struct mparse *);
+void            tbl_restart(int, int, struct tbl_node *);
+void            tbl_free(struct tbl_node *);
+void            tbl_reset(struct tbl_node *);
+enum rofferr    tbl_read(struct tbl_node *, int, const char *, int);
+void            tbl_option(struct tbl_node *, int, const char *, int *);
+void            tbl_layout(struct tbl_node *, int, const char *, int);
+void            tbl_data(struct tbl_node *, int, const char *, int);
+int             tbl_cdata(struct tbl_node *, int, const char *, int);
+const struct tbl_span  *tbl_span(struct tbl_node *);
+int             tbl_end(struct tbl_node **);
+struct eqn_node        *eqn_alloc(int, int, struct mparse *);
+enum rofferr    eqn_end(struct eqn_node **);
+void            eqn_free(struct eqn_node *);
+enum rofferr    eqn_read(struct eqn_node **, int,
+                       const char *, int, int *);
 
 __END_DECLS
 
 __END_DECLS
-
-#endif /*LIBROFF_H*/